@@ -190,7 +190,7 @@ class PathVariablesCheck(Check):
     """Scan ebuild for path variables with various issues."""
 
     _source = sources.EbuildFileRepoSource
-    known_results = frozenset([MissingSlash, UnnecessarySlashStrip, DoublePrefixInPath])
+    known_results = frozenset({MissingSlash, UnnecessarySlashStrip, DoublePrefixInPath})
     prefixed_dir_functions = (
         "insinto",
         "exeinto",
@@ -225,13 +225,19 @@ class PathVariablesCheck(Check):
         # qmake-utils.eclass
         "qt4_get_bindir",
         "qt5_get_bindir",
+        "qt6_get_bindir",
         # s6.eclass
         "s6_get_servicedir",
+        # shell-completion.eclass
+        "get_fishcompdir",
+        "get_zshcompdir",
         # systemd.eclass
         "systemd_get_systemunitdir",
         "systemd_get_userunitdir",
         "systemd_get_utildir",
         "systemd_get_systemgeneratordir",
+        "systemd_get_systempresetdir",
+        "systemd_get_sleepdir",
     )
     prefixed_rhs_variables = (
         # catch silly ${ED}${EPREFIX} mistake ;-)
@@ -368,7 +374,11 @@ class InsintoCheck(Check):
             "/etc/env.d": "doenvd or newenvd",
             "/etc/init.d": "doinitd or newinitd",
             "/etc/pam.d": "dopamd or newpamd from pam.eclass",
+            "/usr/lib/systemd/system": "systemd_dounit or systemd_newunit from systemd.eclass",
+            "/usr/lib/systemd/user": "systemd_douserunit or systemd_newuserunit from systemd.eclass",
             "/usr/share/applications": "domenu or newmenu from desktop.eclass",
+            "/usr/share/fish/vendor_completions.d": "dofishcomp or newfishcomp from shell-completion.eclass",
+            "/usr/share/zsh/site-functions": "dozshcomp or newzshcomp from shell-completion.eclass",
         }
     )
 
@@ -1422,11 +1432,26 @@ class NonPosixHeadTailUsage(results.LineResult, results.Warning):
         return f"line {self.lineno}: non-posix usage of {self.command!r}: {self.line!r}"
 
 
+class NonConsistentTarUsage(results.LineResult, results.Warning):
+    """Using of non-consistent compliant ``tar``.
+
+    The ``tar`` command defaults to reading from stdin, unless this default is
+    changed at compile time or the ``TAPE`` environment variable is set.
+
+    To ensure consistent behavior, the ``-f`` or ``--file`` option should
+    always be given to ensure the input device is chosen explicitly.
+    """
+
+    @property
+    def desc(self):
+        return f"line {self.lineno}: non-consistent usage of tar without '-f' or '--file': {self.line!r}"
+
+
 class NonPosixCheck(Check):
     """Scan ebuild for non-posix usage, code which might be not portable."""
 
     _source = sources.EbuildParseRepoSource
-    known_results = frozenset([NonPosixHeadTailUsage])
+    known_results = frozenset({NonPosixHeadTailUsage, NonConsistentTarUsage})
 
     def __init__(self, options, **kwargs):
         super().__init__(options, **kwargs)
@@ -1445,11 +1470,23 @@ class NonPosixCheck(Check):
                 break
             prev_arg = arg
 
+    def check_tar(self, pkg, call_node):
+        for idx, arg in enumerate(map(pkg.node_str, call_node.children[1:])):
+            if idx == 0 or (arg[:1] == "-" and arg[1:2] != "-"):
+                if "f" in arg:
+                    return
+            elif arg == "--file" or arg.startswith("--file="):
+                return
+        lineno, _ = call_node.start_point
+        yield NonConsistentTarUsage(lineno=lineno + 1, line=pkg.node_str(call_node), pkg=pkg)
+
     def feed(self, pkg):
         for call_node in bash.cmd_query.captures(pkg.tree.root_node).get("call", ()):
             call_name = pkg.node_str(call_node.child_by_field_name("name"))
             if call_name in ("head", "tail"):
                 yield from self.check_head_tail(pkg, call_node, call_name)
+            elif call_name == "tar":
+                yield from self.check_tar(pkg, call_node)
 
 
 class GlobDistdir(results.LineResult, results.Warning):
